from OpenGL.GL import *
from math import sqrt,cos,sin,pi

'''Testobjects for timing: Displaylistcone vs loop cone'''
class Objects3D:
  def __init__(self, diameter=1, height=1, slices=3):
    # Store cone parameter
    self.diameter=diameter
    self.height=height
    self.slices=slices
    
    #calculate vertices of cone
    steps = pi/slices
    round = 0
    count = 0
    self.vertexArray=[[0.0,height,0.0]]
    self.indiceArray=[]
    while round < 2*pi:
      self.vertexArray.append([diameter*sin(round),0,diameter*cos(round)])
      round += steps
      self.indiceArray.append(count)
      count += 1
    # In the TRINAGLE_FAN the second and the last vertex have to be the same
    self.indiceArray.append(self.indiceArray[1])
  
  def displayListCone(self):
    # Generate displaylist from cone methode
    self.dlCone=glGenLists(1)
    glNewList(self.dlCone, GL_COMPILE)
    self.cone()
    glEndList()
    return self.dlCone
    
  # cone slow
##~   def cone(self):
##~     steps = pi/self.slices
##~     round = 0
##~     glBegin(GL_TRIANGLE_FAN)
##~     glVertex3f(0,self.height,0)
##~     while round < 2*pi:
##~       #glNormal(self.diameter*sin(round),0,self.diameter*cos(round))
##~       glVertex3f(self.diameter*sin(round),0,self.diameter*cos(round))
##~       round += steps
##~     glEnd()
  # cone fast
  def cone(self):
    # Draw cone from precalculated values
    glBegin(GL_TRIANGLE_FAN)
    glVertex3f(0,self.height,0)
    for count in range(len(self.vertexArray)):
      #glNormal(self.diameter*sin(round),0,self.diameter*cos(round)) # Only for correct lighting
      glVertex3f(self.vertexArray[count][0], self.vertexArray[count][1], self.vertexArray[count][2])
    glVertex3f(self.vertexArray[1][0], self.vertexArray[1][1], self.vertexArray[1][2])
    glEnd()
    
  def calcNormal(self, xVector, yVector):
    result=[0,0,0]
    result[0] = xVector[1] * yVector[2] - yVector[1] * xVector[2]
    result[1] = -xVector[0] * yVector[2] + yVector[0] * xVector[2]
    result[2] = xVector[0] * yVector[1] - yVector[0] * xVector[1]
    return [result[0],result[1],result[2]]
    
  def arrayCone(self):
    # Draw cone directly from array
    glVertexPointerf(self.vertexArray)
    glEnableClientState(GL_VERTEX_ARRAY)
    glDrawElementsui(GL_TRIANGLE_FAN,self.indiceArray)
    glDisableClientState(GL_VERTEX_ARRAY)
