# Initiate the OpenGL paramters

import sys
from OpenGL.GLUT import *
from OpenGL.GL import *
from OpenGL.GLE import *
from OpenGL.GLU import *
from py_world import VirtualWorld

'''InitGL includes all parameters needed for inital OpenGL setup.''' 
class InitGL:
  '''Initialise an OpenGL windows with the origin at x, y and size of height, width.'''
  def __init__(self, x, y, height, width):
    glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGB | GLUT_DEPTH)
    glutInitWindowSize(height, width)
    glutInitWindowPosition(x,y)
    glutCreateWindow("Python OpenGL Testbench")
    glClearDepth(1.0)
    glEnable(GL_DEPTH_TEST)
    glClearColor(0.0, 0.0, 0.0, 0.0)
    glShadeModel(GL_SMOOTH)
    glOrtho(-10,10,10,-10,10,200)
    glMatrixMode(GL_MODELVIEW)
    # Automatic vector normalise
    glEnable(GL_NORMALIZE)
    gluLookAt(18,35,40,0,0,0,0,1,0)
    # initialize lighting */
    glLightfv(GL_LIGHT0, GL_POSITION,  (40, 10, 0, 1))
    glLightfv(GL_LIGHT0, GL_DIFFUSE, (0.5, 0.5, 0.5, 0.5))
    glLightfv(GL_LIGHT0, GL_AMBIENT, (0.2, 0.2, 0.2, 1))
    glEnable(GL_LIGHT0)
    #glLightfv(GL_LIGHT1, GL_POSITION, (40, 10, 0, 1))
    #print glGetLightiv(GL_LIGHT1, GL_POSITION)
    glLightfv(GL_LIGHT1, GL_DIFFUSE, (0.5, 0.5, 0.5, 0.5))
    #glLightfv(GL_LIGHT1, GL_SPOT_DIRECTION, (1,0,0))
    glLightfv(GL_LIGHT1, GL_SPECULAR, (1,1,1,1))
    #glEnable(GL_LIGHT1)

    glEnable(GL_LIGHTING)
    glColorMaterial(GL_FRONT, GL_DIFFUSE)
    glEnable(GL_COLOR_MATERIAL)
    # glEnable(GL_TEXTURE_2D)
    # ### Instantiate the virtual world ###
    pyWorld = VirtualWorld()
    # #########################
    # setup the callbacks
    glutDisplayFunc(pyWorld.drawScene)
    glutMotionFunc(pyWorld.activeMouse)
    #glutPassiveMotionFunc(pyWorld.passiveMouse)
    glutMouseFunc(pyWorld.completeMouse)
    glutReshapeFunc(pyWorld.resizeScene)
    #glutMouseFunc(pyWorld.completeMouse)
    # When we are doing nothing, redraw the scene.
    glutIdleFunc(pyWorld.drawIdleScene)
    # Register the function called when the keyboard is pressed.  
    glutKeyboardFunc(pyWorld.keyPressed)
    
if __name__ == '__main__':
  # initialize GLUT 
  glutInit(sys.argv)
  # Call init: Parameter(Window Position -> x, y, height, width)
  testbench=InitGL(300,300,800,600)
  # Start Event Processing Engine	
  glutMainLoop()
